@@ -329,13 +329,15 @@ def get_gem( cc, capa ):
 
     # bad sonix camera- crazy default values...
     if "gain" in capa:
-        ga = cc.get_gain()
-        gad = cc.getdef_gain()
         ming = cc.getmin_gain()
         maxg = cc.getmax_gain()
-        ga10 = (ga-ming)/(maxg-ming)
+        ga = cc.get_gain()
+        if (ga>maxg)or (ga<ming): ### if bad values
+            ga=ming
+        gad = cc.getdef_gain()
         if (gad>maxg)or (gad<ming): ### if bad values
             gad=ming
+        ga10 = (ga-ming)/(maxg-ming)
         aga = (ga,gad,ming,maxg,ga10)
 
 
@@ -423,6 +425,8 @@ def set_gem(cc, gain=None, expo=None, mmaga=None):
                 ga = cc.get_gain()
                 ming = cc.getmin_gain()
                 maxg = cc.getmax_gain()
+                if (ga>maxg) or (ga<ming):
+                    ga = ming
                 print(f"i... current gain {ga}   range {ming}, {maxg}")
 
                 ga = int( gain * (maxg-ming)+ming)
@@ -436,6 +440,7 @@ def set_gem(cc, gain=None, expo=None, mmaga=None):
                 print("X... gain noit in capacities")
 
     #if not mmaga is None: # formelly, but from 2206 - I dont want to play gamma
+    # ------------!!!!!!!!!!!------------
     if False: #not mmaga is None:
         if mmaga == "def":
             if "gamma" in capa:
